<img src="https://github.com/LOAMRI/asltk/blob/develop/docs/assets/asltk-logo.png" width=200>

[![Documentation Status](https://readthedocs.org/projects/asltk/badge/?version=latest)](https://asltk.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/LOAMRI/asltk/graph/badge.svg?token=1W8GQ7SLU9)](https://codecov.io/gh/LOAMRI/asltk)
![CI_main](https://github.com/LOAMRI/asltk/actions/workflows/ci_main.yaml/badge.svg)
[![CI_develop](https://github.com/LOAMRI/asltk/actions/workflows/ci_develop.yaml/badge.svg)](https://github.com/LOAMRI/asltk/actions/workflows/ci_develop.yaml)

# Arterial Spin Labeling Toolkit (asltk)

Welcome to the ASLtk project!

Access the [full documentation](https://asltk.readthedocs.io/en/latest/) to check the usage and development of this tool.

## How to install

```bash
pip install asltk
```

## Citation

We appreciate if one or more of the following references can be added in your projects due to the usage of `asltk` outcomes.

* Paper 1
